@@ -32,6 +32,8 @@ from sagemaker_training import (
     logging_config,
 )
 
+logger = logging_config.get_logger()
+
 # Default limit of the stream is 2 ** 16 KB, we can increase it to 128KB in subproc call
 _DEFAULT_BUF_SIZE = 1024 * 64
 
@@ -121,7 +123,9 @@ async def run_async(cmd, processes_per_host, env, cwd, stderr, **kwargs):
     output = await asyncio.gather(
         watch(proc.stdout, processes_per_host), watch(proc.stderr, processes_per_host)
     )
-    return_code = proc.returncode
+    logger.info("Waiting for the process to finish and give a return code.")
+    return_code = await proc.wait()
+    logger.info(f"Done waiting for a return code. Received {return_code} from exiting process.")
     return return_code, output, proc
 
 
@@ -193,6 +197,8 @@ def check_error(cmd, error_class, processes_per_host, cwd=None, capture_error=Tr
         stderr = output[1]
     else:
         stderr = None
+        # remove extra quotes for subprocess.Popen
+        cmd[-1] = cmd[-1].strip('"')
         process = subprocess.Popen(
             cmd, env=os.environ, cwd=cwd or environment.code_dir, stderr=stderr, **kwargs
         )
@@ -253,7 +259,7 @@ class ProcessRunner(object):
                 six.moves.shlex_quote(arg)  # pylint: disable=too-many-function-args
                 for arg in self._args
             ]
-            return ["/bin/sh", "-c", "./%s %s" % (self._user_entry_point, " ".join(args))]
+            return ["/bin/sh", "-c", '"./%s %s"' % (self._user_entry_point, " ".join(args))]
 
     def _python_command(self):  # pylint: disable=no-self-use
         return [python_executable()]
